pytest_requirements 0.1.0 (2024-11-29)
--------------------------------------

Initial release. Supports marking tests using
``@pytest.mark.verifies_requirement("<ID>")`` and ``@pytest.mark.verifies_usecase("<ID>")``
as well as exporting the marker information to the junit xml file.
